==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da_DK">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vælg en eller flere enheder</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Skift til vindue</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Skift til fuld skærm</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vælg en eller flere enheder</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Der blev ikke fundet en filemanager.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installer venligst en filemanager.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Optagelsen er ikke startet, ikke nok disk plads.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Grænsenfor fri disk plads er nået.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grænse for ledig diskplads</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Optagelsen blev stoppet, ikke nok fri disk plads.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Vindue</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Der blev ikke fundet en filemanager.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installer venligst en filemanager.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kildekode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Hjemmeside</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Oversættelser</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donér</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vælg en eller flere enheder</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsæt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Forstørrelse</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsæt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vend horisontalt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vend vertikalt</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Negativ</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Sort hvid</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fjern vinduesramme</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kamera indstillinger</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Nulstil</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Forstørrelse</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedtælling</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videostørrelse:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ledig diskplads:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Optagelsestid:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Video-codec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Lyd-codec</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Optag ikke musemarkør</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minutter</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Start timeren</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stop optagelse efter</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutter</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunder</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosti</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grænse for ledig diskplads</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Vis i systembakke</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekunder der skal ventes inden optagelse</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Led efter opdateringer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tilgængelig</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ikke tilgængelig</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsæt</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Negativ</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Send rapport</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Afspil seneste optagelse</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimeret når optagelse starter</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Starter minimeret</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vend horisontalt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vend vertikalt</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Sort hvid</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fjern vinduesramme</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donér</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Nulstil alle indstillinger ves næste start</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Ophavsret og licens fra billeder</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Skærmudsending</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Afspiller</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Ophavsret og licens fra billeder</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Åben fil</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Forrige ramme</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Næste ramme</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Tavs</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Flyt menu</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.3.0.orig.tar.gz: vokoscreenNG-3.3.0/src/language/da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da_DK">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vælg en eller flere enheder</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Skift til vindue</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Skift til fuld skærm</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vælg en eller flere enheder</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Der blev ikke fundet en filemanager.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installer venligst en filemanager.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Optagelsen er ikke startet, ikke nok disk plads.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Grænsenfor fri disk plads er nået.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grænse for ledig diskplads</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Optagelsen blev stoppet, ikke nok fri disk plads.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Vindue</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Der blev ikke fundet en filemanager.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installer venligst en filemanager.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kildekode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Hjemmeside</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Oversættelser</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donér</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Vælg en eller flere enheder</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsæt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Forstørrelse</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsæt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Forstørrelse</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vend horisontalt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vend vertikalt</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Negativ</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Sort hvid</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fjern vinduesramme</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kamera indstillinger</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Nulstil</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Forstørrelse</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedtælling</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videostørrelse:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ledig diskplads:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Optagelsestid:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Video-codec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Lyd-codec</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Optag ikke musemarkør</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minutter</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Start timeren</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stop optagelse efter</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Timer</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutter</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunder</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosti</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Grænse for ledig diskplads</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Vis i systembakke</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekunder der skal ventes inden optagelse</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Led efter opdateringer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tilgængelig</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ikke tilgængelig</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsæt</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Negativ</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grå</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Send rapport</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Afspil seneste optagelse</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimeret når optagelse starter</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Starter minimeret</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Vend horisontalt</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Vend vertikalt</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Sort hvid</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Fjern vinduesramme</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donér</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Nulstil alle indstillinger ves næste start</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Ophavsret og licens fra billeder</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Skærmudsending</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Afspiller</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ON</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Ophavsret og licens fra billeder</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Åben fil</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Forrige ramme</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Næste ramme</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Tavs</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Flyt menu</translation>
    </message>
</context>
</TS>
